@@ -14,10 +14,7 @@
 
 #include "magics.h"
 
-#if !defined PROJ_H
 typedef struct PJconsts PJ;
-typedef struct projCtx_t PJ_CONTEXT;
-#endif
 
 
 namespace magics {
@@ -43,7 +40,6 @@ protected:
     string from_;
     string to_;
     PJ* converter_;
-    static PJ_CONTEXT* context_;
 
 private:
     //! Copy constructor - No copy allowed
@@ -61,8 +57,8 @@ class LatLonProjP : public ProjP {
 public:
     LatLonProjP() {}
     LatLonProjP(const string& to) : ProjP("EPSG:4326", to) {}
-    int convert(double&, double&) const;
-    int revert(double&, double&) const;
+    int convert(double&, double&) const override;
+    int revert(double&, double&) const override;
 };
 
 }  // namespace magics
