@@ -654,14 +654,16 @@ void GribDecoder::customisedPoints(const Transformation& transformation, Customi
 
         for (map<double, int>::iterator y = xComponent_->yIndex_.begin(); y != xComponent_->yIndex_.end(); ++y) {
             InfoIndex x = xComponent_->xIndex_[y->second];
-            double lat  = y->first;
+    
             int index   = x.offset_;
             for (int i = 0; i < x.nbPoints_; i++) {
                 double lon = x.first_ + (i * x.step_);
+                double lat  = y->first;
                 double u   = xComponent_->data_[index];
                 double v   = yComponent_->data_[index];
                 vector<UserPoint> pos;
                 pos.reserve(5);
+                xComponent_->adjustPosition(lon, lat);
                 transformation.populate(lon, lat, 0, pos);
                 if (pos.empty()) {
                     index++;
@@ -798,8 +800,8 @@ grib_handle* GribDecoder::open(grib_handle* grib, bool sendmsg) {
     if (!handle) {
         if (sendmsg) {
             ostringstream error;
-            error << "can not access position [" << current_position_ << " in " << file_name_ << "]" << std::endl;
-            MagLog::error() << "can not access position [" << current_position_ << " in " << file_name_ << "]"
+            error << "cannot access position [" << current_position_ << " in " << file_name_ << "]" << std::endl;
+            MagLog::error() << "cannot access position [" << current_position_ << " in " << file_name_ << "]"
                             << std::endl;
             MagLog::broadcast();
             valid_ = false;
@@ -996,7 +998,7 @@ bool GribLoop::hasMore() {
     if (file_ == 0) {
         file_ = fopen(path_.c_str(), "r");
         if (!file_) {
-            MagLog::error() << "file can not be opened [" << path_ << "] " << std::strerror(errno) << std::endl;
+            MagLog::error() << "file cannot be opened [" << path_ << "] " << std::strerror(errno) << std::endl;
             throw CannotOpenFile(path_);
         }
     }
@@ -1601,12 +1603,21 @@ void GribDecoder::visit(MetaDataVisitor& meta) {
 
 string GribDecoder::representation() {
     string grid = getstring("typeOfGrid");
-    string proj = getstring("projTargetString", false);
 
+    current_handle_ = field_;
+    // Now warning, no caching
+    string proj =  getstring("projTargetString", false, false);
 
     return (proj.size()) ? "proj" : grid;
 }
 
+string GribDecoder::projString() {
+    current_handle_ = field_;
+    // Now warning, no caching
+    return  getstring("projTargetString", false, false);
+
+}
+
 void GribDecoder::visit(MetaDataCollector& step) {
 
     // Here we gather information for the label!
