@@ -28,12 +28,8 @@
 #include "NetcdfMatrixInterpretor.h"
 #include "TextVisitor.h"
 #include "Tokenizer.h"
-using namespace magics;
 
-#include "magics_windef.h"
-#ifdef MAGICS_ON_WINDOWS
-#include <iterator>
-#endif
+using namespace magics;
 
 
 NetcdfMatrixInterpretor::NetcdfMatrixInterpretor() {}
@@ -66,7 +62,7 @@ bool NetcdfMatrixInterpretor::interpretAsMatrix(Matrix** matrix) {
         x();
         y();
         // get the data ...
-       
+
         //netcdf.setDefault2D(field_);
         map<string, string> first, last;
         setDimensions(dimension_, first, last);
@@ -100,7 +96,7 @@ bool NetcdfMatrixInterpretor::interpretAsMatrix(Matrix** matrix) {
             // for (auto d = rows.begin(); d != rows.end(); ++d)
             //     cout << *d << " " ;
             // cout << endl;
-            
+
             setDimensions(dims, first, last);
             vector<double> data;
             //cout << "GET DATA " << field_ << endl;
@@ -110,7 +106,7 @@ bool NetcdfMatrixInterpretor::interpretAsMatrix(Matrix** matrix) {
             for (vector<double>::iterator d = data.begin(); d != data.end(); d++) {
                 matrix_->push_back(*d);
             }
-            
+
         }
 
 
@@ -124,9 +120,6 @@ bool NetcdfMatrixInterpretor::interpretAsMatrix(Matrix** matrix) {
         MagLog::debug() << "matrix_[" << matrix_->size() << ", " << scaling_ << ", " << offset_ << "\n";
 
 
-        vector<double> col;
-
-
         matrix_->setColumnsAxis(columns_);
         matrix_->setRowsAxis(rows_);
 
@@ -134,6 +127,9 @@ bool NetcdfMatrixInterpretor::interpretAsMatrix(Matrix** matrix) {
         MagLog::dev() << *matrix_ << "\n";
     }
     catch (MagicsException& e) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
         MagLog::error() << e << "\n";
         delete matrix_;
         matrix_ = NULL;
