@@ -16,16 +16,17 @@
 
 */
 
-#include <Arrow.h>
-#include <Flag.h>
-#include <GeoJsonDriver.h>
-#include <Image.h>
-#include <Layer.h>
-#include <Polyline.h>
-#include <Symbol.h>
-#include <Text.h>
+#include "GeoJsonDriver.h"
+#include "Arrow.h"
+#include "Flag.h"
+#include "Image.h"
+#include "Layer.h"
+#include "MagicsGlobal.h"
+#include "Polyline.h"
+#include "Symbol.h"
+#include "Text.h"
 
-#include "magics_windef.h"
+#include "magics.h"
 
 //! For generating ZIP files
 extern "C" {
@@ -34,7 +35,7 @@ extern "C" {
 #define MAXFILENAME 256
 #define WRITEBUFFERSIZE 16384
 #include <fcntl.h>  // open
-#include <cstdio>   // BUFSIZ
+#include <cstdio>  // BUFSIZ
 
 #ifndef MAGICS_ON_WINDOWS
 #include <unistd.h>
@@ -152,11 +153,18 @@ void GeoJsonDriver::close() {
 
                 err = zipOpenNewFileInZip(zf, filename, 0, 0, 0, 0, 0, 0, Z_DEFLATED, Z_DEFAULT_COMPRESSION);
 
-                if (err != ZIP_OK)
+                if (err != ZIP_OK) {
+                    if (MagicsGlobal::strict()) {
+                        throw CannotOpenFile(filename);
+                    }
                     MagLog::error() << "Could NOT open ZIP file " << filename << endl;
+                }
                 else {
                     fin = fopen(filename, "rb");
                     if (fin == 0) {
+                        if (MagicsGlobal::strict()) {
+                            throw CannotOpenFile(filename);
+                        }
                         MagLog::error() << "Open file " << filename << " to be added to ZIP FAILED!" << endl;
                         return;
                     }
@@ -391,8 +399,8 @@ MAGICS_NO_EXPORT void GeoJsonDriver::setNewLineWidth(const MFloat width) const {
   param w width of the line
 
 */
-MAGICS_NO_EXPORT int GeoJsonDriver::setLineParameters(const LineStyle, const MFloat w) const {
-    return 0;
+MAGICS_NO_EXPORT void GeoJsonDriver::setLineParameters(const LineStyle, const MFloat w) const {
+    return;
 }
 
 /*!
