@@ -19,9 +19,9 @@
 #ifndef _GeoJsonDriver_H
 #define _GeoJsonDriver_H
 
-#include <BaseDriver.h>
-#include <GeoJsonDriverAttributes.h>
-#include <XmlNode.h>
+#include "BaseDriver.h"
+#include "GeoJsonDriverAttributes.h"
+#include "XmlNode.h"
 
 namespace magics {
 
@@ -35,14 +35,14 @@ namespace magics {
 class GeoJsonDriver : public BaseDriver, public GeoJsonDriverAttributes {
 public:
     GeoJsonDriver();
-    ~GeoJsonDriver();
-    void open();
-    void close();
+    ~GeoJsonDriver() override;
+    void open() override;
+    void close() override;
 
     /*!
       \brief sets a new XML node
     */
-    void set(const XmlNode& node) {
+    void set(const XmlNode& node) override {
         if (magCompare(node.name(), "GeoJson")) {
             XmlNode basic = node;
             basic.name("driver");
@@ -55,45 +55,45 @@ public:
     /*!
       \brief sets a new map
     */
-    void set(const map<string, string>& map) {
+    void set(const map<string, string>& map) override {
         BaseDriver::set(map);
         GeoJsonDriverAttributes::set(map);
     }
 
 private:
-    MAGICS_NO_EXPORT void startPage() const;
-    MAGICS_NO_EXPORT void endPage() const;
-    MAGICS_NO_EXPORT void project(const Layout& lay) const;
-    MAGICS_NO_EXPORT void redisplay(const StaticLayer&) const;
-    MAGICS_NO_EXPORT void redisplay(const NoDataLayer&) const;
-    MAGICS_NO_EXPORT void redisplay(const StepLayer&) const;
-    MAGICS_NO_EXPORT void redisplay(const SceneLayer&) const;
-    MAGICS_NO_EXPORT void newLayer() const;
-    MAGICS_NO_EXPORT void closeLayer() const;
+    MAGICS_NO_EXPORT void startPage() const override;
+    MAGICS_NO_EXPORT void endPage() const override;
+    MAGICS_NO_EXPORT void project(const Layout& lay) const override;
+    MAGICS_NO_EXPORT void redisplay(const StaticLayer&) const override;
+    MAGICS_NO_EXPORT void redisplay(const NoDataLayer&) const override;
+    MAGICS_NO_EXPORT void redisplay(const StepLayer&) const override;
+    MAGICS_NO_EXPORT void redisplay(const SceneLayer&) const override;
+    MAGICS_NO_EXPORT void newLayer() const override;
+    MAGICS_NO_EXPORT void closeLayer() const override;
 
-    MAGICS_NO_EXPORT void setNewLineWidth(const MFloat) const;
-    MAGICS_NO_EXPORT void setNewColour(const Colour& col) const;
+    MAGICS_NO_EXPORT void setNewLineWidth(const MFloat) const override;
+    MAGICS_NO_EXPORT void setNewColour(const Colour& col) const override;
     MAGICS_NO_EXPORT void writeColour(const Colour& col) const;
-    MAGICS_NO_EXPORT int setLineParameters(const LineStyle style, const MFloat w) const;
+    MAGICS_NO_EXPORT void setLineParameters(const LineStyle style, const MFloat w) const override;
 
-    MAGICS_NO_EXPORT void renderPolyline(const int, MFloat*, MFloat*) const;
-    MAGICS_NO_EXPORT void renderPolyline2(const int n, MFloat* x, MFloat* y) const {}
-    MAGICS_NO_EXPORT void renderSimplePolygon(const int, MFloat*, MFloat*) const;
-    MAGICS_NO_EXPORT void renderSimplePolygon(const Polyline& line) const;
-    MAGICS_NO_EXPORT void renderText(const Text& text) const;
-    MAGICS_NO_EXPORT void circle(const MFloat x, const MFloat y, const MFloat r, const int) const {}
-    MAGICS_NO_EXPORT bool renderPixmap(MFloat, MFloat, MFloat, MFloat, int, int, unsigned char*, int, bool, bool) const;
-    MAGICS_NO_EXPORT bool renderCellArray(const Image& obj) const;
-    MAGICS_NO_EXPORT void renderSymbols(const Symbol& symbol) const;
-    MAGICS_NO_EXPORT void renderWindArrow(const Arrow& arrow) const;
-    MAGICS_NO_EXPORT void renderWindFlag(const Flag& flag) const;
+    MAGICS_NO_EXPORT void renderPolyline(const int, MFloat*, MFloat*) const override;
+    MAGICS_NO_EXPORT void renderPolyline2(const int n, MFloat* x, MFloat* y) const override {}
+    MAGICS_NO_EXPORT void renderSimplePolygon(const int, MFloat*, MFloat*) const override;
+    MAGICS_NO_EXPORT void renderSimplePolygon(const Polyline& line) const override;
+    MAGICS_NO_EXPORT void renderText(const Text& text) const override;
+    MAGICS_NO_EXPORT void circle(const MFloat x, const MFloat y, const MFloat r, const int) const override {}
+    MAGICS_NO_EXPORT bool renderPixmap(MFloat, MFloat, MFloat, MFloat, int, int, unsigned char*, int, bool, bool) const override;
+    MAGICS_NO_EXPORT bool renderCellArray(const Image& obj) const override;
+    MAGICS_NO_EXPORT void renderSymbols(const Symbol& symbol) const override;
+    MAGICS_NO_EXPORT void renderWindArrow(const Arrow& arrow) const override;
+    MAGICS_NO_EXPORT void renderWindFlag(const Flag& flag) const override;
 
     //! Method to print string about this class on to a stream of type ostream (virtual).
-    MAGICS_NO_EXPORT void print(ostream&) const;
-    MAGICS_NO_EXPORT void debugOutput(const string& s) const;
+    MAGICS_NO_EXPORT void print(ostream&) const override;
+    MAGICS_NO_EXPORT void debugOutput(const string& s) const override;
 
     /* K M L specific */
-    MAGICS_NO_EXPORT void redisplay(const LegendLayout& legend) const;
+    MAGICS_NO_EXPORT void redisplay(const LegendLayout& legend) const override;
     MAGICS_NO_EXPORT void closePlacemark() const;
     mutable ofstream pFile_;  //!< Output stream to file.
     mutable Layout* layout_;
