@@ -19,9 +19,9 @@
 #ifndef MPP_PostScriptDriver_H
 #define MPP_PostScriptDriver_H
 
-#include <BaseDriver.h>
-#include <PostScriptDriverAttributes.h>
-#include <XmlNode.h>
+#include "BaseDriver.h"
+#include "PostScriptDriverAttributes.h"
+#include "XmlNode.h"
 
 namespace magics {
 /*! \class PostScriptDriver
@@ -38,14 +38,14 @@ namespace magics {
 class PostScriptDriver : public BaseDriver, public PostScriptDriverAttributes {
 public:
     PostScriptDriver();
-    ~PostScriptDriver();
-    void open();
-    void close();
+    ~PostScriptDriver() override;
+    void open() override;
+    void close() override;
 
     /*!
       \brief sets a new XML node
     */
-    void set(const XmlNode& node) {
+    void set(const XmlNode& node) override {
         if (magCompare(node.name(), "ps") || magCompare(node.name(), "eps") || magCompare(node.name(), "pdf")) {
             XmlNode basic = node;
             basic.name("driver");
@@ -58,7 +58,7 @@ public:
     /*!
       \brief sets a new map
     */
-    void set(const map<string, string>& map) {
+    void set(const map<string, string>& map) override {
         BaseDriver::set(map);
         PostScriptDriverAttributes::set(map);
     }
@@ -71,25 +71,25 @@ public:
     bool isPS() const { return ps_; }
 
 private:
-    MAGICS_NO_EXPORT void startPage() const;
-    MAGICS_NO_EXPORT void endPage() const;
-    MAGICS_NO_EXPORT void project(const Layout& lay) const;
-    MAGICS_NO_EXPORT void unproject() const;
+    MAGICS_NO_EXPORT void startPage() const override;
+    MAGICS_NO_EXPORT void endPage() const override;
+    MAGICS_NO_EXPORT void project(const Layout& lay) const override;
+    MAGICS_NO_EXPORT void unproject() const override;
 
-    MAGICS_NO_EXPORT void setNewLineWidth(const MFloat) const;
-    MAGICS_NO_EXPORT void setNewColour(const Colour& col) const;
+    MAGICS_NO_EXPORT void setNewLineWidth(const MFloat) const override;
+    MAGICS_NO_EXPORT void setNewColour(const Colour& col) const override;
     MAGICS_NO_EXPORT void writeColour() const;
-    MAGICS_NO_EXPORT int setLineParameters(const LineStyle style, const MFloat w) const;
+    MAGICS_NO_EXPORT void setLineParameters(const LineStyle style, const MFloat w) const override;
 
-    MAGICS_NO_EXPORT void renderPolyline(const int, MFloat*, MFloat*) const;
-    MAGICS_NO_EXPORT void renderPolyline2(const int n, MFloat* x, MFloat* y) const;
-    MAGICS_NO_EXPORT void renderSimplePolygon(const int, MFloat*, MFloat*) const;
-    MAGICS_NO_EXPORT void renderSimplePolygon(const Polyline& line) const;
-    MAGICS_NO_EXPORT void renderText(const Text& text) const;
-    MAGICS_NO_EXPORT void circle(const MFloat x, const MFloat y, const MFloat r, const int) const;
-    MAGICS_NO_EXPORT bool renderPixmap(MFloat, MFloat, MFloat, MFloat, int, int, unsigned char*, int, bool, bool) const;
-    MAGICS_NO_EXPORT bool renderCellArray(const Image& obj) const;
-    MAGICS_NO_EXPORT void renderSymbols(const Symbol&) const;
+    MAGICS_NO_EXPORT void renderPolyline(const int, MFloat*, MFloat*) const override;
+    MAGICS_NO_EXPORT void renderPolyline2(const int n, MFloat* x, MFloat* y) const override;
+    MAGICS_NO_EXPORT void renderSimplePolygon(const int, MFloat*, MFloat*) const override;
+    MAGICS_NO_EXPORT void renderSimplePolygon(const Polyline& line) const override;
+    MAGICS_NO_EXPORT void renderText(const Text& text) const override;
+    MAGICS_NO_EXPORT void circle(const MFloat x, const MFloat y, const MFloat r, const int) const override;
+    MAGICS_NO_EXPORT bool renderPixmap(MFloat, MFloat, MFloat, MFloat, int, int, unsigned char*, int, bool, bool) const override;
+    MAGICS_NO_EXPORT bool renderCellArray(const Image& obj) const override;
+    MAGICS_NO_EXPORT void renderSymbols(const Symbol&) const override;
 
     // P O S T S C I P T specific member functions BEGIN
 
@@ -116,8 +116,8 @@ private:
     // P O S T S C I P T specific member functions END
 
     //! Method to print string about this class on to a stream of type ostream (virtual).
-    void print(ostream&) const;
-    MAGICS_NO_EXPORT void debugOutput(const string& s) const;
+    void print(ostream&) const override;
+    MAGICS_NO_EXPORT void debugOutput(const string& s) const override;
 
     //! Copy constructor - No copy allowed
     PostScriptDriver(const PostScriptDriver&);
