@@ -15,15 +15,15 @@
     Started: Fri Oct 26 20:58:21 2007
 */
 
-#include <Image.h>
-#include <ImportObject.h>
-#include <Layer.h>
-#include <Polyline.h>
-#include <SVGDriver.h>
-#include <Symbol.h>
-#include <System.h>
-#include <Text.h>
+#include "SVGDriver.h"
 #include <iomanip>
+#include "Image.h"
+#include "ImportObject.h"
+#include "Layer.h"
+#include "Polyline.h"
+#include "Symbol.h"
+#include "System.h"
+#include "Text.h"
 
 //! For generating SVGZ files
 extern "C" {
@@ -401,7 +401,7 @@ MAGICS_NO_EXPORT void SVGDriver::setNewLineWidth(const MFloat width) const {
   \param w width of the line
 
 */
-MAGICS_NO_EXPORT int SVGDriver::setLineParameters(const LineStyle linestyle, const MFloat w) const {
+MAGICS_NO_EXPORT void SVGDriver::setLineParameters(const LineStyle linestyle, const MFloat w) const {
     const MFloat widi = w * 0.5;
     currentLineType_  = linestyle;
 
@@ -414,18 +414,18 @@ MAGICS_NO_EXPORT int SVGDriver::setLineParameters(const LineStyle linestyle, con
            << ")\""
            << " fill=\"none\"";
 
-    if (currentLineType_ == M_DASH)
+    if (currentLineType_ == LineStyle::DASH)
         stream << " stroke-dasharray=\"" << 2 * widi << "," << 2 * widi << "\"";
-    else if (currentLineType_ == M_DOT)
+    else if (currentLineType_ == LineStyle::DOT)
         stream << " stroke-dasharray=\"" << 1 * widi << "," << 2 * widi << "\"";
-    else if (currentLineType_ == M_CHAIN_DASH)
+    else if (currentLineType_ == LineStyle::CHAIN_DASH)
         stream << " stroke-dasharray=\"" << 4 * widi << "," << 2 * widi << "," << 2 * widi << "," << 2 * widi << "\"";
-    else if (currentLineType_ == M_CHAIN_DOT)
+    else if (currentLineType_ == LineStyle::CHAIN_DOT)
         stream << " stroke-dasharray=\"" << 4 * widi << "," << 2 * widi << "," << 2 * widi << "," << 2 * widi << ","
                << 2 * widi << "\"";
 
     openGroup(stream.str());
-    return 0;
+    return;
 }
 
 
@@ -573,7 +573,7 @@ MAGICS_NO_EXPORT void SVGDriver::renderSimplePolygon(const int n, MFloat* x, MFl
     }
 
     if (count > 2) {
-        if (currentShading_ == M_SH_DOT) {
+        if (currentShading_ == Shading::DOT) {
             const DotShadingProperties* pro = (DotShadingProperties*)currentShadingProperties_;
             const int density               = (int)sqrt(pro->density_);
             if (density <= 0)
@@ -593,7 +593,7 @@ MAGICS_NO_EXPORT void SVGDriver::renderSimplePolygon(const int n, MFloat* x, MFl
                    << "<path fill=\"url(#D_" << svg_pattern_count << ")\" stroke=\"none\" " << stream.str() << "\"/>\n";
             svg_pattern_count++;
         }
-        else if (currentShading_ == M_SH_HATCH) {
+        else if (currentShading_ == Shading::HATCH) {
             const HatchShadingProperties* pro = (HatchShadingProperties*)currentShadingProperties_;
             indexHatch_                       = pro->index_;
             const int density                 = (int)(1. / pro->density_ * 150);
@@ -734,7 +734,7 @@ void SVGDriver::renderSimplePolygon(const magics::Polyline& line) const {
 
     ostringstream strFill;
 
-    if (currentShading_ == M_SH_DOT) {
+    if (currentShading_ == Shading::DOT) {
         const DotShadingProperties* pro = (DotShadingProperties*)currentShadingProperties_;
         const int density               = (int)sqrt(pro->density_);
         if (density <= 0)
@@ -754,7 +754,7 @@ void SVGDriver::renderSimplePolygon(const magics::Polyline& line) const {
         strFill << "url(#D_" << svg_pattern_count << ")";
         svg_pattern_count++;
     }
-    else if (currentShading_ == M_SH_HATCH) {
+    else if (currentShading_ == Shading::HATCH) {
         const HatchShadingProperties* pro = (HatchShadingProperties*)currentShadingProperties_;
         indexHatch_                       = pro->index_;
         const int density                 = (int)(1. / pro->density_ * 150);
@@ -813,9 +813,9 @@ MAGICS_NO_EXPORT void SVGDriver::renderText(const Text& text) const {
 
     Justification horizontalAlign = text.getJustification();
     string justification          = "middle";
-    if (horizontalAlign == MLEFT)
+    if (horizontalAlign == Justification::LEFT)
         justification = "start";
-    else if (horizontalAlign == MRIGHT)
+    else if (horizontalAlign == Justification::RIGHT)
         justification = "end";
 
     VerticalAlign verticalAlign = text.getVerticalAlign();
@@ -836,11 +836,11 @@ MAGICS_NO_EXPORT void SVGDriver::renderText(const Text& text) const {
             const string font              = magfont.name() + "_" + style;
 
             string verticalJustification = "no-change";
-            if (verticalAlign == MBASE)
+            if (verticalAlign == VerticalAlign::BASE)
                 verticalJustification = "alphabetic";
-            else if (verticalAlign == MTOP)
+            else if (verticalAlign == VerticalAlign::TOP)
                 verticalJustification = "hanging";
-            else if (verticalAlign == MHALF)
+            else if (verticalAlign == VerticalAlign::HALF)
                 verticalJustification = "middle";
 
             fontMapIter iter = FontMap_.find(font);
@@ -1247,7 +1247,7 @@ MAGICS_NO_EXPORT void SVGDriver::renderSymbols(const Symbol& symbol) const {
             if (magCompare(logoLocation_, "LOCAL"))
                 logofile = "ecmwf_logo.png";
             else
-                logofile = buildConfigPath("ecmwf_logo.png");
+                logofile = buildSharePath("ecmwf_logo.png");
             svg_output_resource_list_.push_back(logofile);
             pFile_ << "<a xlink:href=\"http://www.ecmwf.int\">"
                    << "<image x=\"" << x - (y * 1.35) << "\" y=\"" << setY(y + (y * .5)) << "\" width=\"" << y * 5.4
@@ -1256,7 +1256,7 @@ MAGICS_NO_EXPORT void SVGDriver::renderSymbols(const Symbol& symbol) const {
         }
         else {
             pFile_ << "<g transform=\"translate(" << x - (y * 1.35) << "," << setY(y + (y * .5)) << ")\">\n";
-            const string s = buildConfigPath("ecmwf_logo_2014.svg");
+            const string s = buildSharePath("ecmwf_logo_2014.svg");
             ifstream psfile(s.c_str());
 
             if (!psfile) {
